@@ -96,7 +96,7 @@ api <- function(user_key, endpoint, parameters=FALSE, custom_headers=NULL, url_p
 #' Provides the binding Version
 #' @return current binding version
 get_binding_version <- function() {
-  bindingVersion <- "1.8.0"
+  bindingVersion <- "1.9.0"
   return(bindingVersion)
 }
 
@@ -214,13 +214,18 @@ error_check <- function(response) {
 #' @param custom_headers - custom headers for the Rosette API
 #' @return Returns the combined h
 get_headers <- function(user_key, content_type="application/json", custom_headers=NULL) {
-  headers <- c("X-RosetteAPI-Key" = user_key, "Content-Type" = content_type, "X-RosetteAPI-Binding" = "R", "X-RosetteAPI-Binding-Version" = get_binding_version(), "user-agent" = "ruseragent")
+  headers <- c("X-RosetteAPI-Key" = user_key, "Content-Type" = content_type, "X-RosetteAPI-Binding" = "R", "X-RosetteAPI-Binding-Version" = get_binding_version(), "user-agent" = get_user_agent())
   if (!is.null(custom_headers)) {
     return(c(headers, custom_headers))
   }
   return(headers)
 }
 
+get_user_agent <- function() {
+  version <- paste(R.Version()$platform, R.Version()$major, R.Version()$minor, sep=".")
+  return(paste("R", get_binding_version(), version, sep="/"))
+}
+
 #' serialize Rosette API parameters
 #' @param parameters - parameters list to be passed to specified Rosette API endpoint
 #' @return Returns the serialized parameters for the Rosette API
